@@ -14,7 +14,7 @@
 
 #include "OutputHandling.h"
 #include "mixmod/Utilities/mixmod.h"
-
+#include "mixmod/Utilities/Util.h"
 /** base class for handling the mixmod outputs and filling them in
  *  a Rcpp list */
 class ClusteringOutputHandling : public OutputHandling
@@ -29,6 +29,11 @@ class ClusteringOutputHandling : public OutputHandling
                              , const XEM::DataType dataType
                              , Rcpp::CharacterVector const & Rcriterion
                              );
+    ClusteringOutputHandling( XEM::ClusteringModelOutput* cMOutput
+                             , Rcpp::S4& xem
+                             , const XEM::DataType dataType
+                              , std::vector <XEM::CriterionName> const & iCriterion
+                             );
 
     /** destructor */
     ~ClusteringOutputHandling();
